<?php
namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Modules\Cotacao\Modules\Pedido\Services\Sup09600IImportacaodeRFPService;
use Zeedhi\Framework\DTO\Response\Message;

class Sup09600IImportacaodeRFPController extends \Zeedhi\Framework\Controller\Report
{

    protected $newCode;
    protected $environment;
    
    protected $errors = array();
    protected $errorMessages = array();
    
    public function __construct($newCode, $environment, Sup09600IImportacaodeRFPService $service)
    {
        $this->newCode       = $newCode;
        $this->environment   = $environment;
        $this->service       = $service;
    }
    
      public function generateCode($newCode) {
        return $this->newCode->getCodeByTableName($newCode, $this->environment->getNrOrgTrab());
    }
    
    public function parseFloat($floatVar){
        if(is_string($floatVar)){
            $floatVar = str_replace(".", "", $floatVar); 
            $floatVar = str_replace(",", ".", $floatVar);
        }
        return $floatVar;
    }
    
    //LOG DE ERRO
    private function addError($errorType, $forn, $index = 0) {
        if (!isset($this->errors[$index])) {
            $this->errors[$index] = array();
        }
        if (!isset($this->errors[$index][$errorType])) {
            $this->errors[$index][$errorType] = array();
        }
        array_push($this->errors[$index][$errorType], $forn);
    }
    
    public function buscaDadosFiltro(DTO\Request $request, DTO\Response $response) {
        try {
            
            $central = $this->service->getcentralCompras();
            if(!$central)
                throw new \Exception("CDFILCENTCMP_NOT_REGISTERED");
                
            $params = $this->service->buscaParametros($central);
            if(empty($params))
                throw new \Exception("NAO_HA_PARAM_CADASTRADOS");
            
            
            $comprador = $this->service->verificaOperadorComprador();
            /*if(empty($comprador))
                throw new \Exception("OPERADOR_NAO_RELACIONADO");*/
            
            $comprador = !empty($comprador) ? $comprador[0] : $comprador;
            
            $datas = $this->service->buscaData($central);
            
            $datas = !empty($datas) ? $datas[0] : $datas;
            
            
            $response->addDataSet(new DataSet("resp", [$datas, $comprador, $central, $params]));    
            
        
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    
    // Adaptado de 'General.js'
    private function valueToFloat($value) {
        if (empty($value)) return 0.0;
        
		if (is_string($value) && $value) {
			if (strpos($value, ',') === false && strpos($value, '.') === false) {
				return floatval($value);
			} else if (strpos($value, ',') > strpos($value, '.')) {
                $value = str_replace('.', '', $value);
                $value = str_replace(',', '.', $value);
				return floatval($value);
			} else if (strpos($value, ',') < strpos($value, '.')) {
			    $value = str_replace(',', '.', $value);
				return floatval($value);
			} else if (strpos($value, ',') === 0 || strpos($value, '.') === 0) {
			    if (strpos($value, ',') === 0) {
			        $value = str_replace(',', '.', $value);
			    }
				return floatval($value);    
			}
		} else {
			return $value;
		}
    }

    
    public function importarXlsRFB(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $answer = $this->service->readXlsHeader($row, $response);
            if($answer['MESSAGE'] == 'SUCCESS'){
            $tableExists = $this->service->readXls($row);
            if($tableExists['MESSAGE'] == 'SUCCESS'){
                $response->addDataSet(new DataSet("importarXLSRFB", ["Importado com sucesso"]));
            }
            }//
            else $response->addMessage(new Message($answer));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 1));
        } 
    }
    
}